# Simulated 3 segment rating (section, channel, and overbank controls)

## Control
A synthetic compound channel was developed for the purposes of simulating streamflows to develop a theoretically defined rating curve.
The rectangular main channel is 100 feet wide and 5 feet tall. A section control resembling a obtuse angled weir roughly 0.3 ft above the main channel bed was inserted downstream of the gaged cross section. 
Floodplains on either side were each 715 ft wide.

## Stage Ranges
- Section control: 5.0 to 5.75 ft
- Channel control: 5.75 to 10 ft
- Overbank control: 10 to 12.18 ft